@@ -137,6 +137,8 @@ def import_keyring():
             "keyring.backends.fail",
             "keyring.backends.kwallet",
             "keyring.backends.macOS",
+            "keyring.backends.OS_X",
+            "keyring.backends._OS_X_API",
             "gdata.docs.service",
             "gdata.service",
             "types",
